Metrics
=======

.. automodule:: smltk.metrics
    :no-members:

.. autosummary::
    :nosignatures:

    smltk.metrics.Metrics

Targets and Predictions management
----------------------------------

.. autosummary::
    :nosignatures:

    smltk.metrics.Metrics.split_tuples
    smltk.metrics.Metrics.prediction

Metrics management
------------------

.. autosummary::
    :nosignatures:

    smltk.metrics.Metrics.create_confusion_matrix
    smltk.metrics.Metrics.get_classification_metrics
    smltk.metrics.Metrics.print_metrics

Model management
----------------

.. autosummary::
    :nosignatures:

    smltk.metrics.Metrics.save_model
    smltk.metrics.Metrics.resume_model

Detailed list
-------------

.. autoclass:: smltk.metrics.Metrics
    :members:
